==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Reviews/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_LANGUAGE","");
define("_PREVIOUS","˹ҡ͹");
define("_NEXT","˹ҶѴ");
define("_YOURNAME","ͤس");
define("_SORTASC","§ҡҡ");
define("_SORTDESC","§ҡҡ仹");
define("_CANCEL","¡ԡ");
define("_YES","ŧ");
define("_NO","赡ŧ");
define("_SCORE","ṹ:");
define("_REPLYMAIN","Ԩó");
define("_ALLOWEDHTML"," HTML ö:");
define("_POSTANON","ѹ֡ ʧ͡");
define("_WRITEREVIEW","¹Ԩó");
define("_WRITEREVIEWFOR","Write a Review for");
define("_ENTERINFO","Please enter information according to the specifications");
define("_PRODUCTTITLE","ͧ");
define("_NAMEPRODUCT","ͧͧ觷Ԩó.");
define("_REVIEW","Review");
define("_CHECKREVIEW","Your actual review. Please observe proper grammar! Make it at least 100 words, OK? You may also use HTML tags if you know how to use them.");
define("_FULLNAMEREQ","Your Full Name. Required.");
define("_REMAIL","Your Email");
define("_REMAILREQ","Your E-mail address. Required.");
define("_SELECTSCORE","This Product Score");
define("_RELATEDLINK","Link Ǣͧ");
define("_PRODUCTSITE","Product Official Website. Make sure your URL starts with \"http://\"");
define("_LINKTITLE","Link Title");
define("_LINKTITLEREQ","Required if you have a related link, otherwise not required.");
define("_RIMAGEFILE","Image Filename");
define("_RIMAGEFILEREQ","Name of the cover image, located in images/reviews/. Not required.");
define("_CHECKINFO","Please make sure that the information entered is 100% valid and uses proper grammar and capitalization. For instance, please do not enter your text in ALL CAPS, as it will be rejected.");
define("_INVALIDTITLE","Invalid Title... Can't be blank");
define("_INVALIDSCORE","Invalid Score... Must be between 1 and 10");
define("_INVALIDTEXT","Invalid Review Text... Can't be blank");
define("_INVALIDHITS","Hits must be a positive integer");
define("_CHECKNAME","You must enter both your name and your email");
define("_INVALIDEMAIL","Invalid email (eg: you@hotmail.com)");
define("_INVALIDLINK","You must enter BOTH a link title and a related link or leave both blank");
define("_ADDED","ѹѹ֡:");
define("_REVIEWER","Ԩó");
define("_REVIEWID","Review ID");
define("_HITS","ӹǹ駼ҹ");
define("_LOOKSRIGHT","Does this looks right?");
define("_RMODIFIED","modified");
define("_RADDED","added");
define("_ADMINLOGGED","йҹк㹰ҹмѴк. Ԩóж١ ");
define("_RTHANKS","͢ͺس س");
define("_MODIFICATION","modification");
define("_ISAVAILABLE","йͧ١㹰ҹº");
define("_EDITORWILLLOOK","ͧóҸԡèоԨóͷӡ");
define("_RBACK","͹Ѻ价Ѫͧ");
define("_RWELCOME","͵͹Ѻ躷Ԩó");
define("_10MOSTPOP","10 ͧԨóҹҡش");
define("_10MOSTREC","10 ͧԨóش");
define("_THEREARE","йպԨó");
define("_REVIEWSINDB","ͧ㹰ҹ");
define("_REVIEWS","Ԩó");
define("_REVIEWSLETTER","Reviews for letter");
define("_NOREVIEWS","There isn't any Review for letter");
define("_TOTALREVIEWS","Total Review(s) found.");
define("_RETURN2MAIN","Return to Main Menu");
define("_REVIEWCOMMENT","Comment on the Review:");
define("_YOURNICK","Your Nickname:");
define("_RCREATEACCOUNT","<a href=modules.php?name=Your_Account>Create</a> an account");
define("_YOURCOMMENT","Your Comment:");
define("_MYSCORE","My Score:");
define("_REVIEWMOD","Review Modification");
define("_RDATE","Date:");
define("_RTITLE","Title:");
define("_RTEXT","Text:");
define("_REVEMAIL","Email:");
define("_RLINK","Link:");
define("_RLINKTITLE","Link Title:");
define("_COVERIMAGE","Cover Image:");
define("_PREMODS","Preview Modifications");
define("_PAGE","Page");
define("_PAGEBREAK","If you want multiple pages you can write <b>&lt;!--pagebreak--&gt;</b> where you want to cut.");
define("_PREVIEW","ͧʴźҾ");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Reviews/language/lang-thai.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_LANGUAGE","");
define("_PREVIOUS","˹ҡ͹");
define("_NEXT","˹ҶѴ");
define("_YOURNAME","ͤس");
define("_SORTASC","§ҡҡ");
define("_SORTDESC","§ҡҡ仹");
define("_CANCEL","¡ԡ");
define("_YES","ŧ");
define("_NO","赡ŧ");
define("_SCORE","ṹ:");
define("_REPLYMAIN","Ԩó");
define("_ALLOWEDHTML"," HTML ö:");
define("_POSTANON","ѹ֡ ʧ͡");
define("_WRITEREVIEW","¹Ԩó");
define("_WRITEREVIEWFOR","Write a Review for");
define("_ENTERINFO","Please enter information according to the specifications");
define("_PRODUCTTITLE","ͧ");
define("_NAMEPRODUCT","ͧͧ觷Ԩó.");
define("_REVIEW","Review");
define("_CHECKREVIEW","Your actual review. Please observe proper grammar! Make it at least 100 words, OK? You may also use HTML tags if you know how to use them.");
define("_FULLNAMEREQ","Your Full Name. Required.");
define("_REMAIL","Your Email");
define("_REMAILREQ","Your E-mail address. Required.");
define("_SELECTSCORE","This Product Score");
define("_RELATEDLINK","Link Ǣͧ");
define("_PRODUCTSITE","Product Official Website. Make sure your URL starts with \"http://\"");
define("_LINKTITLE","Link Title");
define("_LINKTITLEREQ","Required if you have a related link, otherwise not required.");
define("_RIMAGEFILE","Image Filename");
define("_RIMAGEFILEREQ","Name of the cover image, located in images/reviews/. Not required.");
define("_CHECKINFO","Please make sure that the information entered is 100% valid and uses proper grammar and capitalization. For instance, please do not enter your text in ALL CAPS, as it will be rejected.");
define("_INVALIDTITLE","Invalid Title... Can't be blank");
define("_INVALIDSCORE","Invalid Score... Must be between 1 and 10");
define("_INVALIDTEXT","Invalid Review Text... Can't be blank");
define("_INVALIDHITS","Hits must be a positive integer");
define("_CHECKNAME","You must enter both your name and your email");
define("_INVALIDEMAIL","Invalid email (eg: you@hotmail.com)");
define("_INVALIDLINK","You must enter BOTH a link title and a related link or leave both blank");
define("_ADDED","ѹѹ֡:");
define("_REVIEWER","Ԩó");
define("_REVIEWID","Review ID");
define("_HITS","ӹǹ駼ҹ");
define("_LOOKSRIGHT","Does this looks right?");
define("_RMODIFIED","modified");
define("_RADDED","added");
define("_ADMINLOGGED","йҹк㹰ҹмѴк. Ԩóж١ ");
define("_RTHANKS","͢ͺس س");
define("_MODIFICATION","modification");
define("_ISAVAILABLE","йͧ١㹰ҹº");
define("_EDITORWILLLOOK","ͧóҸԡèоԨóͷӡ");
define("_RBACK","͹Ѻ价Ѫͧ");
define("_RWELCOME","͵͹Ѻ躷Ԩó");
define("_10MOSTPOP","10 ͧԨóҹҡش");
define("_10MOSTREC","10 ͧԨóش");
define("_THEREARE","йպԨó");
define("_REVIEWSINDB","ͧ㹰ҹ");
define("_REVIEWS","Ԩó");
define("_REVIEWSLETTER","Reviews for letter");
define("_NOREVIEWS","There isn't any Review for letter");
define("_TOTALREVIEWS","Total Review(s) found.");
define("_RETURN2MAIN","Return to Main Menu");
define("_REVIEWCOMMENT","Comment on the Review:");
define("_YOURNICK","Your Nickname:");
define("_RCREATEACCOUNT","<a href=modules.php?name=Your_Account>Create</a> an account");
define("_YOURCOMMENT","Your Comment:");
define("_MYSCORE","My Score:");
define("_REVIEWMOD","Review Modification");
define("_RDATE","Date:");
define("_RTITLE","Title:");
define("_RTEXT","Text:");
define("_REVEMAIL","Email:");
define("_RLINK","Link:");
define("_RLINKTITLE","Link Title:");
define("_COVERIMAGE","Cover Image:");
define("_PREMODS","Preview Modifications");
define("_PAGE","Page");
define("_PAGEBREAK","If you want multiple pages you can write <b>&lt;!--pagebreak--&gt;</b> where you want to cut.");
define("_PREVIEW","ͧʴźҾ");

?>
